# Conservator CLI

[![Build Status](https://flirjenkins.com/buildStatus/icon?job=FLIR-Ubuntu/conservator-cli/main)](https://flirjenkins.com/job/FLIR-Ubuntu/job/conservator-cli/job/main/)

This library provides a Python API to interface with 
[Conservator](https://flirconservator.com/), as well as a CLI for
simple operations like searching, downloading, and uploading files.

Please visit the [Official Documentation](https://flir.github.io/conservator-cli/)
to get started.

Conservator CLI is licensed under the [MIT License](https://opensource.org/licenses/MIT).
